@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-version = '0.1.16'
+version = '0.1.17'
 release = 'barium'
 
 import os
@@ -77,6 +77,10 @@ class Runner(object):
 
         if verbosity is 0:
             from lettuce.plugins import non_verbose as output
+        elif verbosity is 1:
+            from lettuce.plugins import dots as output
+        elif verbosity is 2:
+            from lettuce.plugins import scenario_names as output
         elif verbosity is 3:
             from lettuce.plugins import shell_output as output
         else:
